@@ -128,21 +128,13 @@ def _init():
 
     ## Loading configs from file, if it's exits:
     _yaml_configs_file_path = os.path.join(_current_dir, 'configs', 'logger.yaml')
-    _json_configs_file_path = os.path.join(_current_dir, 'configs', 'logger.json')
     if os.path.isfile(_yaml_configs_file_path):
         try:
             with open(_yaml_configs_file_path, 'r') as _yaml_configs_file:
-                _configs_dict = yaml.safe_load(_yaml_configs_file)
+                _configs_dict = yaml.safe_load(_yaml_configs_file)['logger']
         except Exception:
             logger.exception(f"Failed to load '{_yaml_configs_file_path}' configs file.")
             exit(2)
-    elif os.path.isfile(_json_configs_file_path):
-        try:
-            with open(_json_configs_file_path, 'r') as _json_configs_file:
-                _configs_dict = json.load(_json_configs_file)
-        except Exception:
-            logger.exception(f"Failed to load '{_json_configs_file_path}' configs file.")
-            exit(2)
 
     _configs_dict['is_debug'] = False
     _configs_dict['level'] = 'INFO'
